==> cssdk-2.0.01.1-sources.jar: com/css/sdk/cservice/adapter/CssTextGridViewAdapter.java <==
package com.css.sdk.cservice.adapter;

import android.content.Context;
import android.graphics.Color;
import android.graphics.drawable.GradientDrawable;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.CheckBox;

import com.css.sdk.R;
import com.css.sdk.cservice.base.utils.LogUtils;
import com.css.sdk.cservice.data.FaqItem;
import com.css.sdk.cservice.data.FaqTypeItem;
import com.css.sdk.cservice.userdata.GlobalData;

import java.util.ArrayList;
import java.util.List;

/**
 * @ProjectName: customerservicesdk
 * @Package: com.css.sdk.cservice.adapter
 * @ClassName: CssTextGridViewAdapter
 * @Description: CssTextGridViewAdapter
 * @Author: Roy
 * @CreateDate: 2020/5/22 14:46
 */

public class CssTextGridViewAdapter extends BaseAdapter {
    private Context mContext;
    private List<ChoseFaqItem> data;
    private GridViewItemClickListener mListener;
    private List<FaqTypeItem> faqs;

    public CssTextGridViewAdapter(Context context, int faqTagId, List<FaqTypeItem> faqs, GridViewItemClickListener clickListener) {
        mContext = context;
        this.faqs = faqs;
        getData(faqTagId);
        mListener = clickListener;
    }

    public interface GridViewItemClickListener {
        public void onGridItemClick(int id);
    }

    private void getData(int faqTagId) {
        List<String> dataStr = getTags();
        data = new ArrayList<>();
        for (int i = 0; i < dataStr.size(); i++) {
            ChoseFaqItem faqItem = new ChoseFaqItem(i, dataStr.get(i));
            if (faqTagId == i) {
                faqItem.checked = true;
            }
            data.add(faqItem);
        }
    }

    private List getTags() {
        if (faqs == null || faqs.size() <= 0) {
            return new ArrayList();
        }
        ArrayList<String> strings = new ArrayList<>();
        for (FaqItem item : faqs) {
            strings.add(item.getFaqTypeByLanguage(mContext));
        }
        return strings;
    }

    @Override
    public int getCount() {
        return data == null ? 0 : data.size();
    }

    @Override
    public Object getItem(int position) {
        return null;
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        ViewHolder viewHolder = null;
        if (convertView == null) {
            convertView = LayoutInflater.from(mContext).inflate(R.layout.css_gridview_faqtag_item, parent, false);
            viewHolder = new ViewHolder();
            viewHolder.content = convertView.findViewById(R.id.css_item_content);
            convertView.setTag(viewHolder);

        } else {
            viewHolder = (ViewHolder) convertView.getTag();
        }
        ChoseFaqItem choseItem = data.get(position);
        viewHolder.content.setText(choseItem.name);
        viewHolder.content.setBackground(mContext.getResources().getDrawable(R.drawable.css_qa_type_bg_default));
        if (choseItem.checked) {
            viewHolder.content.setChecked(true);
            changeBgColor(GlobalData.getUiColor(),GlobalData.getUiColor(),viewHolder.content);
            viewHolder.content.setTextColor(Color.WHITE);
        } else {
            viewHolder.content.setChecked(false);
            changeBgColor(mContext.getResources().getColor(R.color.css_color_text_gray),mContext.getResources().getColor(R.color.css_color_text_gray),viewHolder.content);
            viewHolder.content.setTextColor(Color.WHITE);
        }
        viewHolder.content.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                mListener.onGridItemClick(position);
                refreshData(choseItem);
            }
        });
        return convertView;
    }

    private void refreshData(ChoseFaqItem selected) {
        for (ChoseFaqItem faqItem : data) {
            if (selected.id != faqItem.id) {
                faqItem.checked = false;
            } else {
                faqItem.checked = true;
            }
        }
        notifyDataSetChanged();
    }

    class ViewHolder {
        CheckBox content;
    }

    class ChoseFaqItem {
        int id;
        String name;
        boolean checked;

        ChoseFaqItem(int id, String name) {
            this.id = id;
            this.name = name;
        }
    }

    private void changeCheckBoxStyle(){

    }

    private void changeBgColor(int bgColor,int strokeColor,CheckBox checkBox){
        GradientDrawable mGroupDrawable = (GradientDrawable) checkBox.getBackground();
        if (mGroupDrawable!=null){
            /*设置边框颜色和宽度*/
            mGroupDrawable.setStroke(1, strokeColor);
            /*设置整体背景颜色*/
            mGroupDrawable.setColor(bgColor);
        }else{
            LogUtils.i("no GradientDrawable ");
        }
    }
}

==> cssdk-2.0.02.1-sources.jar: com/css/sdk/cservice/adapter/CssTextGridViewAdapter.java <==
package com.css.sdk.cservice.adapter;

import android.content.Context;
import android.graphics.Color;
import android.graphics.drawable.GradientDrawable;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.CheckBox;

import com.css.sdk.R;
import com.css.sdk.cservice.base.utils.LogUtils;
import com.css.sdk.cservice.data.FaqItem;
import com.css.sdk.cservice.data.FaqTypeItem;
import com.css.sdk.cservice.userdata.GlobalData;

import java.util.ArrayList;
import java.util.List;

/**
 * @ProjectName: customerservicesdk
 * @Package: com.css.sdk.cservice.adapter
 * @ClassName: CssTextGridViewAdapter
 * @Description: CssTextGridViewAdapter
 * @Author: Roy
 * @CreateDate: 2020/5/22 14:46
 */

public class CssTextGridViewAdapter extends BaseAdapter {
    private Context mContext;
    private List<ChoseFaqItem> data;
    private GridViewItemClickListener mListener;
    private List<FaqTypeItem> faqs;

    public CssTextGridViewAdapter(Context context, int faqTagId, List<FaqTypeItem> faqs, GridViewItemClickListener clickListener) {
        mContext = context;
        this.faqs = faqs;
        getData(faqTagId);
        mListener = clickListener;
    }

    public interface GridViewItemClickListener {
        public void onGridItemClick(int id);
    }

    private void getData(int faqTagId) {
        List<String> dataStr = getTags();
        data = new ArrayList<>();
        for (int i = 0; i < dataStr.size(); i++) {
            ChoseFaqItem faqItem = new ChoseFaqItem(i, dataStr.get(i));
            if (faqTagId == i) {
                faqItem.checked = true;
            }
            data.add(faqItem);
        }
    }

    private List getTags() {
        if (faqs == null || faqs.size() <= 0) {
            return new ArrayList();
        }
        ArrayList<String> strings = new ArrayList<>();
        for (FaqTypeItem item : faqs) {
            strings.add(item.type);
        }
        return strings;
    }

    @Override
    public int getCount() {
        return data == null ? 0 : data.size();
    }

    @Override
    public Object getItem(int position) {
        return null;
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        ViewHolder viewHolder = null;
        if (convertView == null) {
            convertView = LayoutInflater.from(mContext).inflate(R.layout.css_gridview_faqtag_item, parent, false);
            viewHolder = new ViewHolder();
            viewHolder.content = convertView.findViewById(R.id.css_item_content);
            convertView.setTag(viewHolder);

        } else {
            viewHolder = (ViewHolder) convertView.getTag();
        }
        ChoseFaqItem choseItem = data.get(position);
        viewHolder.content.setText(choseItem.name);
        viewHolder.content.setBackground(mContext.getResources().getDrawable(R.drawable.css_qa_type_bg_default));
        if (choseItem.checked) {
            viewHolder.content.setChecked(true);
            changeBgColor(GlobalData.getUiColor(),GlobalData.getUiColor(),viewHolder.content);
            viewHolder.content.setTextColor(Color.WHITE);
        } else {
            viewHolder.content.setChecked(false);
            changeBgColor(mContext.getResources().getColor(R.color.css_color_text_gray),mContext.getResources().getColor(R.color.css_color_text_gray),viewHolder.content);
            viewHolder.content.setTextColor(Color.WHITE);
        }
        viewHolder.content.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                mListener.onGridItemClick(position);
                refreshData(choseItem);
            }
        });
        return convertView;
    }

    private void refreshData(ChoseFaqItem selected) {
        for (ChoseFaqItem faqItem : data) {
            if (selected.id != faqItem.id) {
                faqItem.checked = false;
            } else {
                faqItem.checked = true;
            }
        }
        notifyDataSetChanged();
    }

    class ViewHolder {
        CheckBox content;
    }

    class ChoseFaqItem {
        int id;
        String name;
        boolean checked;

        ChoseFaqItem(int id, String name) {
            this.id = id;
            this.name = name;
        }
    }

    private void changeCheckBoxStyle(){

    }

    private void changeBgColor(int bgColor,int strokeColor,CheckBox checkBox){
        GradientDrawable mGroupDrawable = (GradientDrawable) checkBox.getBackground();
        if (mGroupDrawable!=null){
            /*设置边框颜色和宽度*/
            mGroupDrawable.setStroke(1, strokeColor);
            /*设置整体背景颜色*/
            mGroupDrawable.setColor(bgColor);
        }else{
            LogUtils.i("no GradientDrawable ");
        }
    }
}
